@@ -1,6 +1,23 @@
+"""
+Copyright The Cisco Authors
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    https://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+"""
+
 import logging
 from cisco_telescope.instrumentations.requests import RequestsInstrumentorWrapper
 from cisco_telescope.instrumentations.aiohttp import AiohttpInstrumentorWrapper
+from cisco_telescope.instrumentations.pymongo import PymongoInstrumentorWrapper
 from cisco_telescope.instrumentations.grpc import GrpcInstrumentorServerWrapper
 from cisco_telescope.instrumentations.grpc import GrpcInstrumentorClientWrapper
 from .. import consts, options
@@ -15,6 +32,7 @@ class InstrumentationWrapper:
         return {
             consts.REQUESTS_KEY: RequestsInstrumentorWrapper,
             consts.AIOHTTP_KEY: AiohttpInstrumentorWrapper,
+            consts.PYMONGO_KEY: PymongoInstrumentorWrapper,
             consts.AIOHTTP_CLIENT_KEY: AiohttpInstrumentorWrapper,
             consts.GRPC_SERVER_KEY: GrpcInstrumentorServerWrapper,
             consts.GRPC_CLIENT_KEY: GrpcInstrumentorClientWrapper,
